@@ -1,19 +1,8 @@
-/***************************************************************************
-                              ExercisePercentage.cpp
-                             -------------------
-    begin                : 2008/10/10
-    copyright            : (C) 2008 by Tiago Porangaba
-    email                : tiago.porangaba@ltia.fc.unesp.br
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Tiago Porangaba <tiago.porangaba@ltia.fc.unesp.br>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "ExercisePercentage.h"
 
